@@ -31,8 +31,8 @@ test_that("The ssm display methods is working", {
   skip_on_cran()
 
   data("aw2009")
-  res <- ssm_analyze(aw2009, PA:NO, octants())
-  expect_output(print(res), "Profile \\[All\\]:")
+  res <- ssm_analyze(aw2009, scales = 1:8)
+  expect_output(print(res), "# Profile \\[All\\]:")
   expect_output(summary(res), "Statistical Basis:\\t Mean Scores")
   expect_output(summary(res), "Bootstrap Resamples:\\t 2000")
   expect_output(summary(res), "Confidence Level:\\t 0\\.95")
@@ -40,20 +40,33 @@ test_that("The ssm display methods is working", {
   expect_output(summary(res), "Scale Displacements:\\t 90 135 180 225 270 315 360 45")
 
   data("jz2017")
-  res <- ssm_analyze(jz2017, PA:NO, octants(), grouping = Gender)
-  expect_output(print(res), "Profile \\[Female\\]:")
-  expect_output(print(res), "Profile \\[Male\\]:")
+  res <- ssm_analyze(jz2017, scales = 2:9, grouping = "Gender")
+  expect_output(print(res), "# Profile \\[Female\\]:")
+  expect_output(print(res), "# Profile \\[Male\\]:")
 
-  res <- ssm_analyze(jz2017, PA:NO, octants(),
-    grouping = Gender,
-    contrast = "model"
+  res <- ssm_analyze(
+    jz2017, 
+    scales = 2:9,
+    grouping = "Gender",
+    contrast = TRUE
   )
-  expect_output(print(res), "Contrast \\[Male - Female\\]:")
+  expect_output(print(res), "# Profile \\[Female\\]:")
+  expect_output(print(res), "# Profile \\[Male\\]:")
+  expect_output(print(res), "# Contrast \\[Male - Female\\]:")
+  expect_output(print(res), "\u0394 Elevation")
 
-  res <- ssm_analyze(jz2017, PA:NO, octants(),
-    measures = PARPD,
-    grouping = Gender, contrast = "test"
+  res <- ssm_analyze(
+    jz2017, 
+    scales = 2:9,
+    measures = "PARPD",
+    grouping = "Gender", 
+    contrast = TRUE
   )
-  expect_output(print(res), "Contrast \\[PARPD: Male - Female\\]:")
+  expect_output(print(res), "# Contrast \\[PARPD: Male - Female\\]:")
   expect_output(summary(res), "Statistical Basis:\\t Correlation Scores")
 })
+
+test_that("unit classes are working", {
+  expect_snapshot(octants())
+  expect_snapshot(as_radian(octants()))
+})
