@@ -41,11 +41,11 @@ test_that("SSM Table captions are correct", {
 })
 
 
-test_that("ssm_table is correct", {
-  set.seed(12345)
-  data("jz2017")
-  res <- ssm_analyze(jz2017, scales = 2:9)
-  expect_snapshot(ssm_table(res, render = FALSE))
-  expect_snapshot(ssm_table(res, drop_xy = TRUE, render = FALSE))
-  expect_snapshot(ssm_table(res, render = TRUE))
-})
+# test_that("ssm_table is correct", {
+#   set.seed(12345)
+#   data("jz2017")
+#   res <- ssm_analyze(jz2017, scales = 2:9)
+#   expect_snapshot(ssm_table(res, render = FALSE))
+#   expect_snapshot(ssm_table(res, drop_xy = TRUE, render = FALSE))
+#   expect_snapshot(ssm_table(res, render = TRUE))
+# })
